@@ -366,52 +366,52 @@ gnome_cmd_about_plugin_class_init (GnomeCmdAboutPluginClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
 					 g_param_spec_string ("name",
-							      _("Program name"),
-							      _("The name of the program"),
+							      "Program name",
+							      "The name of the program",
 							      NULL,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_VERSION,
 					 g_param_spec_string ("version",
-							      _("Program version"),
-							      _("The version of the program"),
+							      "Program version",
+							      "The version of the program",
 							      NULL,
 							      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 					 PROP_COPYRIGHT,
 					 g_param_spec_string ("copyright",
-							      _("Copyright string"),
-							      _("Copyright information for the program"),
+							      "Copyright string",
+							      "Copyright information for the program",
 							      NULL,
 							      G_PARAM_READWRITE));
 	
 	g_object_class_install_property (object_class,
 					 PROP_COMMENTS,
 					 g_param_spec_string ("comments",
-							      _("Comments string"),
-							      _("Comments about the program"),
+							      "Comments string",
+							      "Comments about the program",
 							      NULL,
 							      G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 					 PROP_AUTHORS,
 					 g_param_spec_value_array ("authors",
-								   _("Authors"),
-								   _("List of authors of the programs"),
+								   "Authors",
+								   "List of authors of the programs",
 								   g_param_spec_string ("author-entry",
-											_("Author entry"),
-											_("A single author entry"),
+											"Author entry",
+											"A single author entry",
 											NULL,
 											G_PARAM_READWRITE),
 								   G_PARAM_WRITABLE));
 	g_object_class_install_property (object_class,
 					 PROP_DOCUMENTERS,
 					 g_param_spec_value_array ("documenters",
-								   _("Documenters"),
-								   _("List of people documenting the program"),
+								   "Documenters",
+								   "List of people documenting the program",
 								   g_param_spec_string ("documenter-entry",
-											_("Documenter entry"),
-											_("A single documenter entry"),
+											"Documenter entry",
+											"A single documenter entry",
 											NULL,
 											G_PARAM_READWRITE),
 								   G_PARAM_WRITABLE));
@@ -419,16 +419,16 @@ gnome_cmd_about_plugin_class_init (GnomeCmdAboutPluginClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_TRANSLATOR_CREDITS,
 					 g_param_spec_string ("translator_credits",
-							      _("Translator credits"),
-							      _("Credits to the translators. This string should be marked as translatable"),
+							      "Translator credits",
+							      "Credits to the translators. This string should be marked as translatable",
 							      NULL,
 							      G_PARAM_READWRITE));
 	
 	g_object_class_install_property (object_class,
 					 PROP_WEBPAGE,
 					 g_param_spec_string ("webpage",
-							      _("Webpage for the plugin"),
-							      _("Webpage"),
+							      "Webpage for the plugin",
+							      "Webpage",
 							      NULL,
 							      G_PARAM_READWRITE));
 	
