@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -78,6 +78,7 @@ struct _GnomeCmdDataPrivate
 	gchar               *quick_connect_user;
 	gint                quick_connect_port;
 	gboolean            honor_expect_uris;
+	gboolean	    use_internal_viewer;
 	gboolean            skip_mounting;
 	gboolean            toolbar_visibility;
 	gboolean            buttonbar_visibility;
@@ -452,7 +453,7 @@ write_string_history (gchar *format, GList *strings)
 	gchar key[128];
 
 	while (strings) {
-		snprintf (key, 128, format, i);
+		snprintf (key, sizeof (key), format, i);
 		gnome_cmd_data_set_string (key, (gchar*)strings->data);
 		strings = strings->next;
 		i++;
@@ -960,6 +961,8 @@ gnome_cmd_data_save                      (void)
 
 	gnome_cmd_data_set_bool   ("/programs/honor_expect_uris",
 				data->priv->honor_expect_uris);
+	gnome_cmd_data_set_bool   ("/programs/use_internal_viewer",
+				data->priv->use_internal_viewer);
 	gnome_cmd_data_set_bool   ("/programs/skip_mounting",
 				data->priv->skip_mounting);
 	gnome_cmd_data_set_bool   ("/programs/toolbar_visibility",
@@ -1228,6 +1231,8 @@ gnome_cmd_data_load                      (void)
 
 	data->priv->honor_expect_uris = gnome_cmd_data_get_bool (
 		"/programs/honor_expect_uris", FALSE);
+	data->priv->use_internal_viewer = gnome_cmd_data_get_bool (
+		"/programs/use_internal_viewer", TRUE);
 	data->priv->skip_mounting = gnome_cmd_data_get_bool (
 		"/programs/skip_mounting", FALSE);
 	data->priv->toolbar_visibility = gnome_cmd_data_get_bool (
@@ -1244,15 +1249,10 @@ gnome_cmd_data_load                      (void)
 	data->priv->sort_direction[1] = gnome_cmd_data_get_bool (
 		"/options/sort_direction_right", FALSE);
 
-	data->priv->viewer = gnome_cmd_data_get_string ("/programs/viewer",
-									 "emacs %s");
-	data->priv->editor = gnome_cmd_data_get_string ("/programs/editor",
-									 "emacs %s");
-	data->priv->differ = gnome_cmd_data_get_string ("/programs/differ",
-									 "meld %s %s");
-	data->priv->term = gnome_cmd_data_get_string (
-		"/programs/term",
-		"xterm -e %s");
+	data->priv->viewer = gnome_cmd_data_get_string ("/programs/viewer", "gedit %s");
+	data->priv->editor = gnome_cmd_data_get_string ("/programs/editor", "gedit %s");
+	data->priv->differ = gnome_cmd_data_get_string ("/programs/differ", "meld %s %s");
+	data->priv->term   = gnome_cmd_data_get_string ("/programs/term", "xterm -e %s");
 
 	data->priv->device_only_icon = gnome_cmd_data_get_bool (
 		"/devices/only_icon", FALSE);
@@ -1910,6 +1910,18 @@ gnome_cmd_data_set_honor_expect_uris (gboolean value)
 	data->priv->honor_expect_uris = value;
 }
 
+gboolean
+gnome_cmd_data_get_use_internal_viewer (void)
+{
+	return data->priv->use_internal_viewer;
+}
+
+
+void
+gnome_cmd_data_set_use_internal_viewer (gboolean value)
+{
+	data->priv->use_internal_viewer = value;
+}
 
 gboolean
 gnome_cmd_data_get_skip_mounting (void)
