@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@
 
 #define FS_PBAR_MAX 50
 
-static GtkTargetEntry drop_types [] = {
+GtkTargetEntry drop_types [] = {
 	{ TARGET_URI_LIST_TYPE, 0, TARGET_URI_LIST },
 	{ TARGET_URL_TYPE, 0, TARGET_URL }
 };
@@ -85,13 +85,11 @@ static guint file_selector_signals[LAST_SIGNAL] = { 0 };
  *******************************/
 
 static void
-set_same_directory (GnomeCmdFileSelector *fs)
+set_same_directory (GnomeCmdFileSelector *fs, GnomeCmdFileSelector *other)
 {
-	GnomeCmdFileSelector *other;
 	GnomeCmdCon *con;
 	GnomeCmdDir *dir;
 
-	other = gnome_cmd_main_win_get_inactive_fs (main_win);
 	con = gnome_cmd_file_selector_get_connection (other);
 	dir = gnome_cmd_file_selector_get_directory (other);
 	if (fs->priv->con != con)
@@ -531,6 +529,10 @@ drag_data_delete (GtkWidget *widget,
 
 	dir = gnome_cmd_file_selector_get_directory (fs);
 	g_return_if_fail (GNOME_CMD_IS_DIR (dir));
+
+	GList *files = gnome_cmd_file_list_get_selected_files (fs->list);
+	gnome_cmd_file_list_remove_files (fs->list, files);
+	g_list_free (files);
 }
 
 
@@ -1651,11 +1653,11 @@ gnome_cmd_file_selector_set_directory (GnomeCmdFileSelector *fs, GnomeCmdDir *di
 	gnome_cmd_dir_ref (dir);
 	
 	if (fs->priv->lwd && fs->priv->lwd != dir) {
-		gnome_cmd_dir_cancel_monitoring (fs->priv->lwd);
 		gnome_cmd_dir_unref (fs->priv->lwd);
 	}
 
 	if (fs->priv->cwd) {
+		gnome_cmd_dir_cancel_monitoring (fs->priv->cwd);
 		fs->priv->lwd = fs->priv->cwd;
 		gtk_signal_disconnect_by_data (GTK_OBJECT (fs->priv->lwd), fs);
 		fs->priv->connected_dir = NULL;
@@ -2031,10 +2033,15 @@ on_create_symlink_ok (GnomeCmdStringDialog *string_dialog,
 	result = gnome_vfs_create_symbolic_link (
 		uri, gnome_cmd_file_get_uri_str (fs->priv->sym_file));
 
-	gnome_vfs_uri_unref (uri);
-	
-	if (result == GNOME_VFS_OK)
+	if (result == GNOME_VFS_OK) {
+		gchar *uri_str = gnome_vfs_uri_to_string (uri, 0);
+		gnome_cmd_dir_file_created (fs->priv->cwd, uri_str);
+		g_free (uri_str);
+		gnome_vfs_uri_unref (uri);	
 		return TRUE;
+	}
+	
+	gnome_vfs_uri_unref (uri);
 	
 	gnome_cmd_string_dialog_set_error_desc (
 		string_dialog, g_strdup (gnome_vfs_result_to_string (result)));
@@ -2090,6 +2097,10 @@ gnome_cmd_file_selector_keypressed (GnomeCmdFileSelector *fs,
 			case GDK_KP_Enter:
 				add_file_to_cmdline (fs, TRUE);
 				return TRUE;
+			
+			case GDK_greater:
+				set_same_directory (gnome_cmd_main_win_get_inactive_fs (main_win),fs);
+				return TRUE;
 		}
 	}
 	else if (state_is_shift (event->state)) {
@@ -2166,7 +2177,8 @@ gnome_cmd_file_selector_keypressed (GnomeCmdFileSelector *fs,
 				return TRUE;
 
 			case GDK_period:
-				set_same_directory (fs);
+				set_same_directory (fs,
+					gnome_cmd_main_win_get_inactive_fs (main_win));
 				return TRUE;
 		}
 	}
@@ -2225,7 +2237,7 @@ gnome_cmd_file_selector_create_symlink (GnomeCmdFileSelector *fs, GnomeCmdFile *
 	GtkWidget *dialog;
 
 	fname = get_utf8 (gnome_cmd_file_get_name (finfo));
-	text = g_strdup_printf ("Symlink to %s", fname);
+	text = g_strdup_printf (_("Symlink to %s"), fname);
 	g_free (fname);
 	dialog = gnome_cmd_string_dialog_new (_("Create Symbolic Link"),
 										  labels,
