@@ -1,6 +1,6 @@
 /*
     GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2003 Marcus Bjurman
+    Copyright (C) 2001-2006 Marcus Bjurman
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,7 +53,7 @@ static gchar *pixmap_files[NUM_PIXMAPS] = {
 	"gnome_cmd_arrow_down.xpm",
 	"gnome_cmd_arrow_blank.xpm",
 	"server.xpm",
-	"gcmd-icon1.xpm",
+	"gnome-commander.xpm",
 	"exec.xpm",
 	"exec_wheel.xpm",
 	"mkdir.xpm",
